@@ -1210,6 +1210,7 @@ class BaseTagger(BaseParser):
                         model, save_to, model_save_method,
                         (ds_train, ds_test),
                         (train[0], test[0]) if test else train[0],
+                        device=device,
                         control_metric=control_metric, best_score=best_score,
                         **params, transform_kwargs=word_transform_kwargs,
                         seed=None, log_file=log_file
@@ -1264,9 +1265,6 @@ class BaseTagger(BaseParser):
             tags_to_remove=tags_to_remove
         ) if self._test_corpus is not None else None
 
-        if device:
-            torch.cuda.set_device(device)
-
         # 2. Create datasets
         def stage_ds(idx):
             if log_file:
